.. django-optionsfield documentation master file, created by
   sphinx-quickstart on Tue Jul 21 21:09:09 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-optionsfield's documentation!
===============================================

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

